@@ -2,10 +2,19 @@ from enum import Enum
 
 
 class Step(int, Enum):
+    pass
+
+
+class FeslStep(Step):
     hello = 1
     login = 2
 
 
+class TheaterStep(Step):
+    conn = 1
+    user = 2
+
+
 class Namespace(bytes, Enum):
     pc = b'battlefield'
     xbox360 = b'xbox'
@@ -27,7 +36,10 @@ class Platform(int, Enum):
 
 DEFAULT_BUFFER_SIZE = 8096
 HEADER_LENGTH = 12
-FESL_DETAILS = {
+VALID_HEADER_TYPES = [b'acct', b'fsys', b'rank',
+                      b'CONN', b'USER', b'LLST', b'LDAT', b'GLST', b'GDAT', b'GDET', b'PDAT', b'PING']
+VALID_HEADER_ERROR_INDICATORS = [b'ngam', b'nrom']
+BACKEND_DETAILS = {
     Platform.pc: {
         'host': 'bfbc2-pc-server.fesl.ea.com',
         'port': 18321,
